Toolbar Mockup — Bristlenose

## New toolbar — all round-rect buttons

Codebook (new window icon) · Tag filter · View switcher · Copy CSV
↑ All four controls use the same .toolbar-btn round-rect treatment.
Codebook opens a new window. Tag filter and view switcher have dropdown arrows.

## Current toolbar (reference)

Tag filter and view switcher are borderless text-only
↑ Current toolbar for comparison — tag filter and view switcher are borderless text.